<?php

namespace Bixo\Report\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Report\Http\Requests\ReportRequest;
use Bixo\Report\Models\Report;

/**
 * Admin web controller class.
 */
class ReportWorkflowController extends BaseController
{

    /**
     * Workflow controller function for report.
     *
     * @param Model   $report
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ReportRequest $request, Report $report, $step)
    {

        try {

            $report->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('report::report.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/report/report/' . $report->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/report/report/' . $report->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for report.
     *
     * @param Model   $report
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Report $report, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $report->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('report::report.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('report::admin.report.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('report::admin.report.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('report::admin.report.message', $data)->render();

        }

    }
}
