<?php

namespace Bixo\Report\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Report\Models\Report;

class ReportPolicy
{

    /**
     * Determine if the given user can view the report.
     *
     * @param UserPolicy $user
     * @param Report $report
     *
     * @return bool
     */
    public function view(UserPolicy $user, Report $report)
    {
        if ($user->canDo('report.report.view') && $user->isAdmin()) {
            return true;
        }

        return $report->user_id == user_id() && $report->user_type == user_type();
    }

    /**
     * Determine if the given user can create a report.
     *
     * @param UserPolicy $user
     * @param Report $report
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('report.report.create');
    }

    /**
     * Determine if the given user can update the given report.
     *
     * @param UserPolicy $user
     * @param Report $report
     *
     * @return bool
     */
    public function update(UserPolicy $user, Report $report)
    {
        if ($user->canDo('report.report.edit') && $user->isAdmin()) {
            return true;
        }

        return $report->user_id == user_id() && $report->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given report.
     *
     * @param UserPolicy $user
     * @param Report $report
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Report $report)
    {
        return $report->user_id == user_id() && $report->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given report.
     *
     * @param UserPolicy $user
     * @param Report $report
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Report $report)
    {
        if ($user->canDo('report.report.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given report.
     *
     * @param UserPolicy $user
     * @param Report $report
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Report $report)
    {
        if ($user->canDo('report.report.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
