<?php

namespace Bixo\Report\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Bixo\Report\Models\Report;

class ReportAction
{
    /**
     * Perform the complete action.
     *
     * @param Report $report
     *
     * @return Report
     */
    public function complete(Report $report)
    {
        try {
            $report->status = 'complete';
            return $report->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Report $report
     *
     * @return Report
     */public function verify(Report $report)
    {
        try {
            $report->status = 'verify';
            return $report->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Report $report
     *
     * @return Report
     */public function approve(Report $report)
    {
        try {
            $report->status = 'approve';
            return $report->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Report $report
     *
     * @return Report
     */public function publish(Report $report)
    {
        try {
            $report->status = 'publish';
            return $report->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Report $report
     *
     * @return Report
     */
    public function archive(Report $report)
    {
        try {
            $report->status = 'archive';
            return $report->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Report $report
     *
     * @return Report
     */
    public function unpublish(Report $report)
    {
        try {
            $report->status = 'unpublish';
            return $report->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
