<?php

namespace Bixo\Report\Workflow;

use Bixo\Report\Models\Report;
use Validator;

class ReportValidator
{

    /**
     * Determine if the given report is valid for complete status.
     *
     * @param Report $report
     *
     * @return bool / Validator
     */
    public function complete(Report $report)
    {
        return Validator::make($report->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given report is valid for verify status.
     *
     * @param Report $report
     *
     * @return bool / Validator
     */
    public function verify(Report $report)
    {
        return Validator::make($report->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given report is valid for approve status.
     *
     * @param Report $report
     *
     * @return bool / Validator
     */
    public function approve(Report $report)
    {
        return Validator::make($report->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given report is valid for publish status.
     *
     * @param Report $report
     *
     * @return bool / Validator
     */
    public function publish(Report $report)
    {
        return Validator::make($report->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given report is valid for archive status.
     *
     * @param Report $report
     *
     * @return bool / Validator
     */
    public function archive(Report $report)
    {
        return Validator::make($report->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given report is valid for unpublish status.
     *
     * @param Report $report
     *
     * @return bool / Validator
     */
    public function unpublish(Report $report)
    {
        return Validator::make($report->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
